ClockPainter class

Inheritance

Constructors

ClockPainter({required double angle, required double hourAngle, required double minuteAngle, required double secondAngle, required TimePickerStyle pickerStyle, required Color dialColor, required Color dialTextColor, required Color dialSelectedTextColor, required Color primaryColor, Color? handColor, Color? selectionBubbleColor, double? strokeWidth, double? centerDotRadius, required PickerMode currentMode, required int selectedHour, required int selectedMinute, required int selectedSecond, required bool use24HourFormat, required bool showSeconds, required bool isAM, required String periodName, TextStyle? centerLabelStyle, TextStyle? centerTimeStyle, TextStyle? centerPeriodStyle})
const

Properties

angle double
final
centerDotRadius double?
final
centerLabelStyle TextStyle?
final
centerPeriodStyle TextStyle?
final
centerTimeStyle TextStyle?
final
currentMode PickerMode
final
dialColor Color
final
dialSelectedTextColor Color
final
dialTextColor Color
final
handColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
hourAngle double
final
isAM bool
final
minuteAngle double
final
periodName String
final
pickerStyle TimePickerStyle
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondAngle double
final
selectedHour int
final
selectedMinute int
final
selectedSecond int
final
selectionBubbleColor Color?
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
showSeconds bool
final
strokeWidth double?
final
use24HourFormat bool
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant ClockPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited