CustomTimePicker class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomTimePicker
Constructors
- CustomTimePicker({Key? key, required dynamic onTimeSelected(TimeOfDayWithSeconds), TimeOfDayWithSeconds? initialTime, bool showSeconds = false, bool use24HourFormat = false, TimePickerStyle pickerStyle = TimePickerStyle.standard, String? titleText, TextStyle? titleStyle, TextAlign? titleAlignment, AlignmentGeometry? titlePosition, EdgeInsetsGeometry? titlePadding, bool showTitle = true, TextStyle? timeSegmentStyle, TextStyle? activeTimeSegmentStyle, TextStyle? separatorStyle, TextStyle? amPmTextStyle, TextStyle? activeAmPmTextStyle, TextStyle? centerLabelStyle, TextStyle? centerTimeStyle, TextStyle? centerPeriodStyle, BorderRadius? borderRadius, BorderRadius? segmentBorderRadius, Color? primaryColor, Color? accentColor, Color? textColor, Color? backgroundColor, Color? dialBackgroundColor, Color? dialTextColor, Color? dialSelectedTextColor, Color? handColor, Color? selectionBubbleColor, double? strokeWidth, double? centerDotRadius})
-
const
Properties
- accentColor → Color?
-
final
- activeAmPmTextStyle → TextStyle?
-
final
- activeTimeSegmentStyle → TextStyle?
-
final
- amPmTextStyle → TextStyle?
-
final
- backgroundColor → Color?
-
final
- borderRadius → BorderRadius?
-
final
- centerDotRadius → double?
-
final
- centerLabelStyle → TextStyle?
-
final
- centerPeriodStyle → TextStyle?
-
final
- centerTimeStyle → TextStyle?
-
final
- dialBackgroundColor → Color?
-
final
- dialSelectedTextColor → Color?
-
final
- dialTextColor → Color?
-
final
- handColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialTime → TimeOfDayWithSeconds?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTimeSelected → dynamic Function(TimeOfDayWithSeconds)
-
final
- pickerStyle → TimePickerStyle
-
final
- primaryColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentBorderRadius → BorderRadius?
-
final
- selectionBubbleColor → Color?
-
final
- separatorStyle → TextStyle?
-
final
- showSeconds → bool
-
final
- showTitle → bool
-
final
- strokeWidth → double?
-
final
- textColor → Color?
-
final
- timeSegmentStyle → TextStyle?
-
final
- titleAlignment → TextAlign?
-
final
- titlePadding → EdgeInsetsGeometry?
-
final
- titlePosition → AlignmentGeometry?
-
final
- titleStyle → TextStyle?
-
final
- titleText → String?
-
final
- use24HourFormat → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomTimePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited